package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// DataCenterTable
// @Summary    	 数据图表
// @Tags         数据中心------嘉俊
// @Description  数据中心-数据图表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterTableReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterTableRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/table [POST]
func DataCenterTable(c *gin.Context) {
	var req md.DataCenterTableReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	if req.StartDate == "" || req.EndDate == "" {
		e.OutErr(c, 400, e.NewErr(400, "筛选时间不能为空"))
		return
	}
	res := svc.DataCenterTable(c, req)
	e.OutSuc(c, res, nil)
	return
}

// DataCenterRecordTotal
// @Summary    	 数据明细合计
// @Tags         数据中心------嘉俊
// @Description  数据中心-数据明细合计
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterTableReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterTotalData     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/record/total [POST]
func DataCenterRecordTotal(c *gin.Context) {
	var req md.DataCenterTableReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	if req.StartDate == "" || req.EndDate == "" {
		e.OutErr(c, 400, e.NewErr(400, "筛选时间不能为空"))
		return
	}
	res := svc.DataCenterRecordTotal(c, req)
	e.OutSuc(c, res, nil)
	return
}

// DataCenterRecordList
// @Summary    	 数据明细
// @Tags         数据中心------嘉俊
// @Description  数据中心-数据明细
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterRecordReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterRecordRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/record/list [POST]
func DataCenterRecordList(c *gin.Context) {
	var req md.DataCenterRecordReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	if req.StartDate == "" || req.EndDate == "" {
		e.OutErr(c, 400, e.NewErr(400, "筛选时间不能为空"))
		return
	}
	res := svc.DataCenterRecordList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// DataCenterRecordOutPut
// @Summary    	 数据明细-导出
// @Tags         数据中心------嘉俊
// @Description  数据中心-数据明细-导出
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterRecordOutPutReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/record/output [POST]
func DataCenterRecordOutPut(c *gin.Context) {
	var req md.DataCenterRecordOutPutReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	if req.StartDate == "" || req.EndDate == "" {
		e.OutErr(c, 400, e.NewErr(400, "筛选时间不能为空"))
		return
	}
	svc.DataCenterRecordOutPut(c, req)
	return
}

// DataCenterSelectData
// @Summary    	 筛选条件
// @Tags         数据中心------嘉俊
// @Description  数据中心-筛选条件
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Success      200   {string}	      "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/select/data [GET]
func DataCenterSelectData(c *gin.Context) {
	svc.DataCenterSelectData(c)
}
